Vue.component('configuration', {
	data: function () {
        return {            
			status: "",
			port: "",
			portsList: []
        }
    },
	computed: {
		running: function() {
			return this.status == 'running' ? true : false;
		},
		tooltip: function() {
			return this.status == 'running' ? 'Daemon running on ' + this.port + ' port' : this.status; 
		}
	},
	methods: {
		getStatus: function() {
			var $self = this;
		
			$.ajax({
				method: "GET",
				cache: false,
				url: Ekey.Url.DaemonStatus,
				dataType: "json"
			})
			.done(function (response) {
				$self.status = response.status;
				$self.port = response.port;
				
				$self.getSerialPortsList();
			})
			.fail(function (xhr, textStatus, errorThrown) {
				console.log(textStatus);
			});
		},
		getSerialPortsList: function() {
			var $self = this;
			
			$.ajax({
				method: "GET",
				cache: false,
				url: Ekey.Url.SerialPortsList,
				dataType: "json"
			})
			.done(function (response) {
				$self.portsList = response.ports;				
			})
			.fail(function (xhr, textStatus, errorThrown) {
				console.log(textStatus);
			});
		},
		stop: function() {
			var $self = this;
			
			$.ajax({
				method: "GET",
				cache: false,
				url: Ekey.Url.DaemonStop,
				dataType: "json"
			})
			.done(function (response) {				
				if (response.success) {
					$self.$buefy.toast.open({
						duration: 2000,
						message: 'Daemon stopped.',
						position: 'is-bottom',
						type: 'is-success'
					});
					
					$self.getStatus();
				} else {
					console.log(response);
				}						
			})
			.fail(function (xhr, textStatus, errorThrown) {
				console.log(textStatus);
			});
		},
		start: function() {
			var $self = this;
			
			$.ajax({
				method: "GET",
				cache: false,
				url: Ekey.Url.DaemonStart,
				dataType: "json"
			})
			.done(function (response) {				
				if (response.success) {
					$self.$buefy.toast.open({
						duration: 2000,
						message: 'Daemon started.',
						position: 'is-bottom',
						type: 'is-success'
					});
					
					$self.getStatus();
				} else {
					console.log(response);
				}				
			})
			.fail(function (xhr, textStatus, errorThrown) {
				console.log(textStatus);
			});
		},
		setSerialPort: function() {			
			var $self = this;
			
			var data = {
				port: $self.port
			};
			
			$.ajax({
				method: "POST",
				url: Ekey.Url.SetSerialPort,
				dataType: "text",
				data: 'data=' + encodeURIComponent(JSON.stringify(data))
			})
			.done(function (response) {				
				var result = JSON.parse(response);
				
				if (result.success) {
					$self.$buefy.toast.open({
						duration: 3000,
						message: 'Port changed successfully, daemon now can be started.',
						position: 'is-bottom',
						type: 'is-success'
					});
				} else {
					console.log(response);
				}
			})
			.fail(function(xhr, textStatus, errorThrown) {
				console.log(textStatus);
			});
		}
	},
	created: function() {
		var $self = this;
		
		this.$eventBus.$on('get-deamon-status', function() {
			$self.getStatus();
		});		
	}
});