var ScannerModal = Vue.component('ScannerModal', {
	props: ['scanner', 'actionObjects', 'fingerObjects'],
	events: ['saved', 'removed'],
	template:'#scanner-modal-template',
	methods: {
		save: function() {
			var $self = this;			
			
			$.ajax({
				method: "POST",
				url: Ekey.Url.ScannersSave,
				dataType: "text",
				data: 'data=' + encodeURIComponent(JSON.stringify($self.scanner))
			})
			.done(function (response) {
				var result = JSON.parse(response);				
				
				if (result.success) {
					$self.$parent.close();
					$self.$emit("saved");					
				} else {
					console.log(response);
				}
			})
			.fail(function(xhr, textStatus, errorThrown) {
				console.log(textStatus);
			});
		},
		remove: function() {
			var $self = this;
			
			$.ajax({
				method: "POST",
				url: Ekey.Url.ScannersDelete,
				dataType: "text",
				data: {
					scanner: $self.scanner.id
				}
			})
			.done(function (response) {
				var result = JSON.parse(response);				
				
				if (result.success) {
					$self.$parent.close();
					$self.$emit("removed");					
				} else {
					console.log(response);
				}
			})
			.fail(function(xhr, textStatus, errorThrown) {
				console.log(textStatus);
			});
		}
	}
});

Vue.component('scanners-list', {
	data: function () {
        return {
            data: [],
            loading: false,
            selected: null
        }
    },
	methods: {
        loadAsyncData: function() {
            var $self = this;
            this.loading = true;
            this.data = [];

            $.ajax({
                method: "GET",
				cache: false,
                url: Ekey.Url.ScannersList,
                dataType: "json"
            })
            .done(function (response) {
                $self.data = response.data;
                $self.loading = false;
            })
            .fail(function (xhr, textStatus, errorThrown) {
				console.log(textStatus);
			});
        },
        onClick: function(row) {			
			var obj = {};
			Object.assign(obj, row);
			
			this.$buefy.modal.open({				
                parent: this,
				props:{
					scanner: obj,
					actionObjects: Ekey.objBool,
					fingerObjects: Ekey.objUint16
				},
				events: {
					saved: this.saved,
					removed: this.removed
				},
                component: ScannerModal,
                hasModalCard: true,
                customClass: 'custom-ekey-modal'
            });
        },
		calculateRowClass: function(row, index) {
			if (row.active == 1 && row.is_authorized == 0) {
				return 'objects-row-unspec';
			}
			
			return row.active != 1 && 'objects-row-error';
		},
		saved: function() {
			this.loadAsyncData();
		},
		removed: function() {
			this.loadAsyncData();
		},
		reloadList: function() {
			this.loadAsyncData();
		}
    },
	created: function() {
		var $self = this;
		
		this.$eventBus.$on('get-scanners-list', function() {
			$self.loadAsyncData();
		});
	}
});