var UserInformationModal = Vue.component('UserInformationModal', {
	props: ['user'],
	events: ['saved'],
	template:'#user-info-modal-template',
	data: function() {
		return {
			actions: []
		}		
	},
	methods: {
		save: function() {
			var $self = this;			
			
			$.ajax({
				method: "POST",
				url: Ekey.Url.UsersSave,
				dataType: "text",
				data: 'data=' + encodeURIComponent(JSON.stringify($self.user))
			})
			.done(function (response) {
				var result = JSON.parse(response);				
				
				if (result.success) {
					$self.$parent.close();
					$self.$emit("saved");
				} else {
					console.log(response);
				}
			})
			.fail(function(xhr, textStatus, errorThrown){
				console.log(textStatus);
			});		
		}
	},
	created: function() {
		var $self = this;
		
		$.ajax({
			method: "GET",
			cache: false,
			url: Ekey.Url.ActionsList,
			dataType: "json"
		})
		.done(function (response) {
			$self.actions = response.data
		})
		.fail(function (xhr, textStatus, errorThrown) {
			console.log(textStatus);
		});		
	}
});

var EnrollUserModal = Vue.component('EnrollUserModal', {
	props: ['user', 'finger', 'scanner'],
	events: ['enrolled'],
	template:'#enroll-user-modal-template',
	data: function() {
		return {
			users: [],
			scanners: [],
			fingers: []
		}		
	},
	computed: {
		activeScanners: function () {
			return _.filter(this.scanners, function(s) { return s.active == 1; });
		}
	},
	methods: {
		enroll: function() {
			var $self = this;			
			
			$.ajax({
				method: "POST",
				url: Ekey.Url.UsersEnroll,
				dataType: "text",
				data: 'data=' + encodeURIComponent(JSON.stringify({user: this.user, finger: this.finger, scanner: this.scanner}))
			})
			.done(function (response) {
				var result = JSON.parse(response);
				
				if (result.success) {
					$self.$parent.close();
					$self.$emit("enrolled");
				} else {
					console.log(response);
				}
			})
			.fail(function(xhr, textStatus, errorThrown){
				console.log(textStatus);
			});		
		}
	},
	created: function() {
		var $self = this;
		
		$.ajax({
			method: "GET",
			cache: false,
			url: Ekey.Url.ScannersUsersSelect,
			dataType: "json"
		})
		.done(function (response) {
			$self.users = response.users;
			$self.fingers = response.fingers;
			$self.scanners = response.scanners;
		})
		.fail(function (xhr, textStatus, errorThrown) {
			console.log(textStatus);
		});
	}
});

var DeleteFingerModal = Vue.component('DeleteFingerModal', {
	props: ['user', 'finger', 'deleteall'],
	events: ['deleted'],
	template:'#delete-finger-modal-template',
	data: function() {
		return {
			users: [],
			scanners: []
		}		
	},
	methods: {
		remove: function() {
			var $self = this;			
			
			var data = encodeURIComponent(JSON.stringify({user: $self.user, finger: $self.finger}));
			if ($self.deleteall == 'on') {
				data = encodeURIComponent(JSON.stringify({user: $self.user, deleteall: $self.deleteall}));
			}
			
			$.ajax({
				method: "POST",
				url: Ekey.Url.UsersDelete,
				dataType: "text",
				data: 'data=' + data
			})
			.done(function (response) {
				var result = JSON.parse(response);				
				
				if (result.success) {
					$self.$parent.close();
					$self.$emit("deleted");
				} else {
					console.log(response);
				}
			})
			.fail(function(xhr, textStatus, errorThrown){
				console.log(textStatus);
			});
		}
	},
	created: function() {
		var $self = this;
		
		$.ajax({
			method: "GET",
			cache: false,
			url: Ekey.Url.AllUsers,

			dataType: "json"
		})
		.done(function (response) {
			$self.users = response.data;
			$self.fingers = response.fingers;
		})
		.fail(function (xhr, textStatus, errorThrown) {
			console.log(textStatus);
		});
	}
});

Vue.component('users-list', {
	data: function () {
        return {
            data: [],
            loading: false,
			daemonStatus: ""
        }
    },
	computed: {
		daemonStopped: function() {
			return this.daemonStatus != 'running' ? true : false;
		}
	},
	methods: {
        loadAsyncData: function() {
            var $self = this;
            this.loading = true;
            this.data = [];

            $.ajax({
                method: "GET",
				cache: false,
                url: Ekey.Url.UsersList,
                dataType: "json"
            })
            .done(function (response) {
                $self.data = response.data;
				$self.daemonStatus = response.deamonStatus;
                $self.loading = false;
            })
            .fail(function () { });            
        },
		openUserInformationModal: function(row) {
			var $self = this;
			var obj = {};
			Object.assign(obj, row);
			
			$self.$buefy.modal.open({				
				parent: $self,
				props:{
					user: obj					
				},
				events: {
					saved: $self.saved
				},
				component: UserInformationModal,
				hasModalCard: true,
				customClass: 'custom-ekey-modal'
			});
		},
		openEnrollUserModal: function(id, finger) {
			var $self = this;
			var userId = id;			
			
			$self.$buefy.modal.open({				
				parent: $self,
				props:{
					user: userId,
					finger: finger,
					scanner: null
				},
				events: {
					enrolled: $self.enrolled
				},
				component: EnrollUserModal,
				hasModalCard: true,
				customClass: 'custom-ekey-modal'
			});
		},
		openDeleteFingerModal: function(id, finger) {
			var $self = this;
			var userId = id;
			
			$self.$buefy.modal.open({				
				parent: $self,
				props:{
					user: userId,
					finger: finger,
					deleteall: false
				},
				events: {
					deleted: $self.deleted
				},
				component: DeleteFingerModal,
				hasModalCard: true,
				customClass: 'custom-ekey-modal'
			});
		},
		saved: function() {
			this.loadAsyncData();
		},
		enrolled: function() {
			this.loadAsyncData();
		},
		deleted: function() {
			this.loadAsyncData();
		}
    },
	created: function() {
		var $self = this;
		
		this.$eventBus.$on('get-users-list', function() {
			$self.loadAsyncData();
		});
	}
});